"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;
exports.ruleName = exports.messages = void 0;
var _stylelint = require("stylelint");
var _utils = require("../../utils");
const declarationValueIndex = require('stylelint/lib/utils/declarationValueIndex');
const ruleName = (0, _utils.namespace)('font-weight-no-ignored-values');
exports.ruleName = ruleName;
const messages = _stylelint.utils.ruleMessages(ruleName, {
  rejected: weight => `Unexpected font-weight "${weight}"`
});
exports.messages = messages;
const acceptedWeights = ['400', '700', 'normal', 'bold'];
function _default(actual) {
  return function (root, result) {
    const validOptions = _stylelint.utils.validateOptions(result, ruleName, {
      actual
    });
    if (!validOptions) {
      return;
    }
    root.walkDecls(/^font-weight$/i, decl => {
      if (acceptedWeights.indexOf(decl.value) > -1) {
        return;
      }
      const weightValueOffset = decl.value.indexOf(decl.value);
      const index = declarationValueIndex(decl) + weightValueOffset;
      _stylelint.utils.report({
        message: messages.rejected(decl.value),
        node: decl,
        result,
        ruleName,
        index
      });
    });
  };
}