"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;
exports.ruleName = exports.messages = void 0;
var _stylelint = require("stylelint");
var _utils = require("../../utils");
const declarationValueIndex = require('stylelint/lib/utils/declarationValueIndex');
const ruleName = (0, _utils.namespace)('line-height-no-value-without-unit');
exports.ruleName = ruleName;
const messages = _stylelint.utils.ruleMessages(ruleName, {
  rejected: height => `Unexpected line-height "${height}", expect a value with units`
});
exports.messages = messages;
const lengthRe = /^(0$|(?:[+-]?(?:\d*\.)?\d+(?:[Ee][+-]?\d+)?)(?=px|PX|rem$))/;
const viewportUnitRe = /^([+-]?[0-9.]+)(vh|vw|vmin|vmax)$/;
function _default(actual) {
  return function (root, result) {
    const validOptions = _stylelint.utils.validateOptions(result, ruleName, {
      actual
    });
    if (!validOptions) {
      return;
    }
    root.walkDecls(/^line-height$/i, decl => {
      if (lengthRe.test(decl.value) || viewportUnitRe.test(decl.value)) {
        return;
      }
      const valueOffset = decl.value.indexOf(decl.value);
      const index = declarationValueIndex(decl) + valueOffset;
      _stylelint.utils.report({
        message: messages.rejected(decl.value),
        node: decl,
        result,
        ruleName,
        index
      });
    });
  };
}